@@ -1,41 +1,22 @@
-#' Bayesian meta-analysis to investigate the relationship between treatment 
-#' effect and underlying risk.
+#' @title Bayesian meta-analysis for external validity using baseline risk
 #'
-#' This function performers a Bayesian meta-analysis to analyse heterogeneity of
-#' the treatment effect as a function of the baseline risk. The function fits a 
-#' hierarchical meta-regression model based on a bivariate random effects model. 
-#' 
-#' The number of events in the control and treated group are modeled with two
-#' conditional Binomial distributions and the random-effects are based on a 
-#' bivariate scale mixture of Normals.
-#' 
-#' The function calculates the implicit hierarchical meta-regression, where the 
-#' treatment effect is regressed to the baseline risk (rate of events in the control
-#' group). The scale mixture weights are used to adjust for internal validity and 
-#' structural outliers identification.
-#' 
-#' Computations are done by calling JAGS (Just Another Gibbs Sampler) to perform
-#' MCMC (Markov Chain Monte Carlo) sampling and returning an object of the
-#' class \emph{mcmc.list}.
 #'
-#' Installation of JAGS: It is important to note that R 3.3.0 introduced a major change in the
-#' use of toolchain for Windows. This new toolchain is incompatible with older packages written in C++.
-#' As a consequence, if the installed version of JAGS does not match the R installation, then the rjags
-#' package will spontaneously crash. Therefore, if a user works with R version >= 3.3.0, then JAGS must
-#' be installed with the installation program JAGS-4.2.0-Rtools33.exe. For users who continue using R 3.2.4 or
-#' an earlier version, the installation program for JAGS is the default installer JAGS-4.2.0.exe.
+#' @description This function performers a Bayesian meta-analysis to analyse heterogeneity of
+#' the treatment effect as a function of the baseline risk. The function fits a
+#' hierarchical meta-regression model based on a bivariate random effects model.
+#'
 #'
 #'
 #' @param data            A data frame where the first four columns containing the number of events in
-#'                        the control group (yc), the number of patients in the control group (nc), 
+#'                        the control group (yc), the number of patients in the control group (nc),
 #'                        the number of events in the treatment group (yt) and the number of patients in the
-#'                        treatment group (nt). If two.by.two = TRUE a data frame where each line 
+#'                        treatment group (nt). If two.by.two = TRUE a data frame where each line
 #'                        contains the trial results with column names: yc, nc, yt, nt.
 #'
 #' @param two.by.two      If TRUE indicates that the trial results are with names: yc, nc, yt, nt.
 #'
 #' @param re              Random effects distribution for the resulting model. Possible
-#'                        values are \emph{normal} for bivariate random effects and \emph{sm} 
+#'                        values are \emph{normal} for bivariate random effects and \emph{sm}
 #'                        for scale mixtures.
 #'
 #' @param link            The link function used in the model. Possible values are
@@ -45,12 +26,12 @@
 #'
 #' @param mean.mu.2       Prior mean of treatment effect, default value is 0.
 #'
-#' @param sd.mu.1         Prior standard deviation of mu.1, default value is 1. The default prior of mu.1 is a 
-#'                        logistic distribution with mean 0 and dispersion 1. The implicit prior for mu.1 in 
+#' @param sd.mu.1         Prior standard deviation of mu.1, default value is 1. The default prior of mu.1 is a
+#'                        logistic distribution with mean 0 and dispersion 1. The implicit prior for mu.1 in
 #'                        the probability scale is a uniform between 0 and 1.
 #'
-#' @param sd.mu.2         Prior standard deviation of mu.2, default value is 1. The default prior of mu.2 is a 
-#'                        logistic distribution with mean 0 and dispersion 1. The implicit prior for mu.2 in 
+#' @param sd.mu.2         Prior standard deviation of mu.2, default value is 1. The default prior of mu.2 is a
+#'                        logistic distribution with mean 0 and dispersion 1. The implicit prior for mu.2 in
 #'                        the probability scale is a uniform between 0 and 1.
 #'
 #' @param sigma.1.upper   Upper bound of the uniform prior of sigma.1, default value is 5.
@@ -69,7 +50,7 @@
 #'
 #' @param df.upper        Upper bound of the prior of df. The default value is 30.
 #'
-#' @param split.w         Split the w parameter in two independent weights one for each random effect. 
+#' @param split.w         Split the w parameter in two independent weights one for each random effect.
 #'                        The default value is FALSE.
 #'
 #' @param nr.chains       Number of chains for the MCMC computations, default 5.
@@ -93,25 +74,42 @@
 #' The results of the object of the class metadiag can be extracted with R2jags or with rjags. In addition
 #' a summary, a print and a plot functions are implemented for this type of object.
 #'
-#' @references Verde, P.E, Ohmann, C., Icks, A. and Morbach, S. (2016) Bayesian evidence synthesis and combining randomized and nonrandomized results: a case study in diabetes. Statistics in Medicine. Volume 35, Issue 10, 10 May 2016, Pages: 1654 to 1675.
 #'
-#' @references Verde, P.E. and Curcio, D. (2017) Hierarchical Meta-Regression Modelling: The Case of The Pneumococcal Polysaccharide Vaccine. Technical Report. 
-#' 
-#' @references Verde, P.E. (2018) The Hierarchical Meta-Regression Approach and Learning from Clinical Evidence. Technical report.
+#' @details The number of events in the control and treated group are modeled with two
+#' conditional Binomial distributions and the random-effects are based on a
+#' bivariate scale mixture of Normals.
+#'
+#' The function calculates the implicit hierarchical meta-regression, where the
+#' treatment effect is regressed to the baseline risk (rate of events in the control
+#' group). The scale mixture weights are used to adjust for internal validity and
+#' structural outliers identification.
+#'
+#' Computations are done by calling JAGS (Just Another Gibbs Sampler) to perform
+#' MCMC (Markov Chain Monte Carlo) sampling and returning an object of the
+#' class \emph{mcmc.list}.
+#'
+#'
+#' @references Verde, P.E. and Curcio, D. (2019) Hierarchical Meta-Regression Modelling: The Case
+#' of The Pneumococcal Polysaccharide Vaccine. Technical Report.
+#'
+#' @references Verde, P.E. (2019) The hierarchical meta-regression approach and learning from clinical evidence.
+#' Biometrical Journal. 1 - 23.
+#'
+#' @references Verde, P. E. (2017) Two Examples of Bayesian Evidence Synthesis with the Hierarchical Meta-Regression Approach. Chap.9, pag 189-206. Bayesian Inference, ed. Tejedor, Javier Prieto. InTech.
 #'
 #' @examples
-#' 
-#' 
+#'
+#' \donttest{
 #' library(jarbes)
-#' 
+#'
 #' # This example is used to test the function and it runs in about 5 seconds.
-#' # In a real application you must increase the number of MCMC interations. 
+#' # In a real application you must increase the number of MCMC interations.
 #' # For example use: nr.burnin = 5000 and nr.iterations = 20000
-#' 
+#'
 #' data(ppvcap)
 #' dat <- ppvcap[, c("yt","nt","yc","nc")]
 #' res.hmr.1 <- metarisk(dat,             # Data frame
-#'                       two.by.two = FALSE,    # Data is given as: (tp, n1, fp, n2)
+#'                       two.by.two = FALSE,    # Data is given as: (yt, nt, yc, nc)
 #'                       re = "sm",             # Random effects distribution
 #'                       link = "logit",        # Link function
 #'                       sd.Fisher.rho   = 1.7, # Prior standard deviation of correlation
@@ -121,30 +119,30 @@
 #'                       nr.iterations = 1000,  # Total iterations
 #'                       nr.chains = 2,         # Number of chains
 #'                       r2jags = TRUE)         # Use r2jags as interface to jags
-#'                       
+#'
 #' print(res.hmr.1, digits = 3)
-#' 
 #'
-#' 
-#' \donttest{
-#' 
+#'
+#'
+#'
+#'
 #' # The following examples corresponds to Section 4 in Verde (2018).
-#' # These are simulated examples to investigate internal and external validity
-#' # bias in meta-analysi.
-#' 
+#' # These are simulated examples to investigate internal and
+#' # external validity bias in meta-analysis.
 #'
-#'library(MASS)
-#'library(ggplot2)
-#'library(jarbes)
-#'library(gridExtra)
-#'library(mcmcplots)
+#'
+#' library(MASS)
+#' library(ggplot2)
+#' library(jarbes)
+#' library(gridExtra)
+#' library(mcmcplots)
 #'
 #' #Experiment 1: External validity bias
 #'
 #'set.seed(2018)
-#' # mean control 
+#' # mean control
 #' pc <- 0.7
-#' # mean treatment 
+#' # mean treatment
 #'pt <- 0.4
 #' # reduction of "amputations" odds ratio
 #'OR <- (pt/(1-pt)) /(pc/(1-pc))
@@ -163,14 +161,14 @@
 #'# rho
 #'rho.true <- -0.5
 #'Sigma <- matrix(c(sigma.1.true^2, sigma.1.true*sigma.2.true*rho.true,
-#'                  sigma.1.true*sigma.2.true*rho.true, sigma.2.true^2), 
+#'                  sigma.1.true*sigma.2.true*rho.true, sigma.2.true^2),
 #'                  byrow = TRUE, ncol = 2)
 #'Sigma
 #'
 #'theta <- mvrnorm(35, mu = c(mu.1.true, mu.2.true),
 #'                 Sigma = Sigma )
-#'                 
-#'                 
+#'
+#'
 #'plot(theta, xlim = c(-2,3))
 #'abline(v=mu.1.true, lty = 2)
 #'abline(h=mu.2.true, lty = 2)
@@ -201,12 +199,12 @@
 #'##########################################################
 #'incr.e <- 0.05
 #'incr.c <- 0.05
-#'n11 <- AD.s1$yt 
-#'n12 <- AD.s1$yc 
-#'n21 <- AD.s1$nt - AD.s1$yt 
+#'n11 <- AD.s1$yt
+#'n12 <- AD.s1$yc
+#'n21 <- AD.s1$nt - AD.s1$yt
 #'n22 <- AD.s1$nc - AD.s1$yc
 #'AD.s1$TE <- log(((n11 + incr.e) * (n22 + incr.c))/((n12 + incr.e) * (n21 + incr.c)))
-#'AD.s1$seTE <- sqrt((1/(n11 + incr.e) + 1/(n12 + incr.e) + 
+#'AD.s1$seTE <- sqrt((1/(n11 + incr.e) + 1/(n12 + incr.e) +
 #'                      1/(n21 + incr.c) + 1/(n22 + incr.c)))
 #'
 #'Pc <- ((n12 + incr.c)/(AD.s1$nc + 2*incr.c))
@@ -221,7 +219,7 @@
 #'###################################################################
 #'
 #'res.s1 <- metarisk(AD.s1, two.by.two = FALSE, sigma.1.upper = 5,
-#'                   sigma.2.upper = 5, 
+#'                   sigma.2.upper = 5,
 #'                   sd.Fisher.rho = 1.5)
 #'
 #'print(res.s1, digits = 4)
@@ -238,35 +236,35 @@
 #'sd(OR.eta.hat)
 #'quantile(OR.eta.hat, probs = c(0.025, 0.5, 0.975))
 #'
-#'ind.random <- sample(1:18000, size = 80, replace = F)
+#'ind.random <- sample(1:18000, size = 80, replace = FALSE)
 #'
-#'##############################################################               
+#'##############################################################
 #' p1 <- ggplot(dat.points, aes(x = logitPc, y = TE, size = N.total)) +
 #'       xlab("logit Baseline Risk")+
 #'       ylab("log(Odds Ratio)")+
 #'       geom_point(shape = 21, colour = "blue") + scale_size_area(max_size=10)+
-#'       scale_x_continuous(name= "Rate of The Control Group (logit scale)", 
+#'       scale_x_continuous(name= "Rate of The Control Group (logit scale)",
 #'                        limits=c(-2, 5)) +
 #'      geom_vline(xintercept = mu.T, colour = "blue", size = 1, lty = 1) +
 #'        geom_hline(yintercept = eta.true, colour = "blue", size = 1, lty = 1)+
-#'          geom_abline(intercept=beta.0[ind.random], 
+#'          geom_abline(intercept=beta.0[ind.random],
 #'                    slope=beta.1[ind.random],alpha=0.3,
 #'                    colour = "grey", size = 1.3, lty = 2)+
-#'          geom_abline(intercept = mean(beta.0[ind.random]), 
+#'          geom_abline(intercept = mean(beta.0[ind.random]),
 #'          slope = mean(beta.1[ind.random]),
 #'          colour = "black", size = 1.3, lty = 2)+
 #'      geom_abline(intercept = mu.2.true, slope = sigma.2.true/sigma.1.true * rho.true,
-#'      colour = "blue", size = 1.2)+ theme_bw() 
-#'      
-#'      
+#'      colour = "blue", size = 1.2)+ theme_bw()
+#'
+#'
 #'# Posterior of eta.hat
 #'
 #'eta.df <- data.frame(x = OR.eta.hat)
 #'
 #'
-#'p2 <- ggplot(eta.df, aes(x = x)) + 
+#'p2 <- ggplot(eta.df, aes(x = x)) +
 #'  xlab("Odds Ratio") +
-#'  ylab("Posterior distribution")+ 
+#'  ylab("Posterior distribution")+
 #'  geom_histogram(fill = "royalblue", colour = "black", alpha= 0.4, bins=80) +
 #'  geom_vline(xintercept = exp(eta.true), colour = "black", size = 1.7, lty = 1)+
 #'  geom_vline(xintercept = c(0.28, 0.22, 0.35), colour = "black", size = 1, lty = 2)+
@@ -274,13 +272,10 @@
 #'
 #'
 #' grid.arrange(p1, p2, ncol = 2, nrow = 1)
-
-
-
 #'
 #' #Experiment 2: Internal validity bias and assesing conflict of evidence between the RCTs.
-#' 
-#' 
+#'
+#'
 #' set.seed(2018)
 #' ind <- sample(1:35, size=5, replace = FALSE)
 #' ind
@@ -291,15 +286,15 @@
 #'AD.s4.contaminated$nt <- AD.s1$nc[ind]
 #'AD.s4.contaminated <- rbind(AD.s4.contaminated,
 #'                          AD.s1[-ind,1:4])
-#'                          
-#' res.s4 <- metarisk(AD.s4.contaminated, 
+#'
+#' res.s4 <- metarisk(AD.s4.contaminated,
 #'                    two.by.two = FALSE,
 #'                    re = "sm",
 #'                    sigma.1.upper = 3,
-#'                    sigma.2.upper = 3, 
+#'                    sigma.2.upper = 3,
 #'                    sd.Fisher.rho = 1.5,
 #'                    df.estimate = TRUE)
-#'                    
+#'
 #'print(res.s4, digits = 4)
 #'
 #'attach.jags(res.s4)
@@ -315,7 +310,7 @@
 #'                          y = w.s,
 #'                         ylo  = w.l,
 #'                         yhi  = w.u)
-#'                         
+#'
 #'# Outliers:
 #'w.col <- studies %in% ind
 #'w.col.plot <- ifelse(w.col, "black", "grey")
@@ -327,14 +322,14 @@
 #'   # d$y gives center point
 #'   # d$ylo gives lower limits
 #'   # d$yhi gives upper limits
-#'   
-#'   p <- ggplot(d, aes(x=x, y=y, ymin=ylo, ymax=yhi) )+ 
+#'
+#'   p <- ggplot(d, aes(x=x, y=y, ymin=ylo, ymax=yhi) )+
 #'        geom_pointrange( colour=w.col.plot, lwd =0.8)+
-#'        coord_flip() + geom_hline(yintercept = 1, lty=2)+ 
+#'        coord_flip() + geom_hline(yintercept = 1, lty=2)+
 #'        xlab("Study ID") +
 #'        ylab("Scale mixture weights") + theme_bw()
 #'        return(p)}
-#'        
+#'
 #'w.plot(dat.weights)
 #'
 #' #List of other possible statistical models:
@@ -354,13 +349,13 @@
 #'
 #' #    6) For the scale mixture random effects:
 #' #       df = 4 => "fix the degrees of freedom to a particual value".
-#' #       Note that df = 1 fits a Cauchy bivariate distribution to 
+#' #       Note that df = 1 fits a Cauchy bivariate distribution to
 #' #       the random effects.
 #' #End of the examples
-#' 
+#'
 #' }
-#' 
-#' 
+#'
+#'
 #' @import R2jags
 #' @import rjags
 #'
@@ -399,7 +394,7 @@ metarisk <- function(data,
                      )UseMethod("metarisk")
 
 #' @export
-#' 
+#'
 metarisk.default <- function(
           # Data
            data,
@@ -435,17 +430,16 @@ metarisk.default <- function(
           )
 {
 
-# Model errors checking-----
 
-if(re=="normal" & split.w==TRUE)stop("Normal random effects and splitting weights are not compatible options")
+  # Model errors checking-----
+  check.model.1 = re=="normal" & split.w==TRUE
+  if(check.model.1)stop("Normal random effects and splitting weights are not compatible options")
 
-re.test <- re %in% c("normal", "sm")
+  re.test <- re %in% c("normal", "sm")
+  if(!re.test)stop("This random effects distribution is not implemented")
 
-if(!re.test)stop("This random effects distribution is not implemented")
-
-link.test <- link %in% c("logit", "cloglog", "probit")
-
-if(!link.test)stop("This link function is not implemented")
+  link.test <- link %in% c("logit", "cloglog", "probit")
+  if(!link.test)stop("This link function is not implemented")
 
 	# Setting up hyperparameters ...
 	      pre.mu.1 <- 1/(sd.mu.1*sd.mu.1)
@@ -470,12 +464,16 @@ if(!link.test)stop("This link function is not implemented")
 
 	N <- length(nc)
 
-  # Data errors
-  if(yc>nc || yt>nt)stop("the data is inconsistent")
-  #if(missing(data))stop("NAs are not alow in this function")
 
-#-----
-# Data, initial values and parameters .....................................................
+	# Data errors (fixing failure: length > 1 in coercion to logical)
+	# But it does not work! CRAN still give me the error.
+
+	check.dat <- any(yc>nc || yt>nt)
+	if(check.dat)stop("the data is inconsistent")
+	#if(any(missing(data)))stop("NAs are not alow in this function")
+
+
+  # Data, initial values and parameters ..............................
 	data.model <-
             list(N = N,
 	              yc = yc,
@@ -492,9 +490,15 @@ if(!link.test)stop("This link function is not implemented")
 	  pre.Fisher.rho = pre.Fisher.rho
 	 )
 
-	if(re == "sm" & df.estimate == TRUE){data.model$df.lower <- df.lower
-	                                     data.model$df.upper <- df.upper}
-	if(re == "sm" & df.estimate == FALSE){data.model$df <- df}
+	check.model.2 = re == "sm" & df.estimate == TRUE
+	if(check.model.2){
+	  data.model$df.lower <- df.lower
+	  data.model$df.upper <- df.upper}
+
+	check.model.3 = re == "sm" & df.estimate == FALSE
+	if(check.model.3){
+	  data.model$df <- df}
+
 
   # Parameters to monitor ....................................................................
 	parameters.model <-
@@ -510,32 +514,40 @@ if(!link.test)stop("This link function is not implemented")
       "beta.0",
       "beta.1")
 
-# This take the weights for the scale mixture random effects model, etc...
+ # This take the weights for the scale mixture random effects model, etc...
+ # Model parameters
 
-        if(re == "sm" & split.w == TRUE & df.estimate == TRUE)
-          parameters.model <- c(parameters.model, "w1", "w2", "p.w1", "p.w2", "df")
-        else
-          if(re == "sm" & split.w == TRUE & df.estimate == FALSE)
-            parameters.model <- c(parameters.model, "w1", "w2", "p.w1", "p.w2")
-	      else
-          if(re=="sm" & split.w == FALSE & df.estimate == TRUE)
-            parameters.model <- c(parameters.model, "w", "p.w", "df")
-	     else
-	       if(re=="sm" & split.w == FALSE & df.estimate == FALSE)
-	         parameters.model <- c(parameters.model, "w", "p.w")
+	check.q1 = re == "sm" & split.w == TRUE  & df.estimate == TRUE
+	check.q2 = re == "sm" & split.w == TRUE  & df.estimate == FALSE
+	check.q3 = re == "sm" & split.w == FALSE & df.estimate == TRUE
+	check.q4 = re == "sm" & split.w == FALSE & df.estimate == FALSE
+
+	if(check.q1)
+	  parameters.model <- c(parameters.model, "w1", "w2", "p.w1", "p.w2", "df")
+	else
+	  if(check.q2)
+	    parameters.model <- c(parameters.model, "w1", "w2", "p.w1", "p.w2")
+	else
+	  if(check.q3)
+	    parameters.model <- c(parameters.model, "w", "p.w", "df")
+	else
+	  if(check.q4)
+	    parameters.model <- c(parameters.model, "w", "p.w")
+
+ # Model BUGS script
 
 
-# Model BUGS script
-
-#----
 blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimate = FALSE)
 {
 
-   if(split.w == FALSE & df.estimate == TRUE ) re <- "sm.df"
-   if(split.w == TRUE  & df.estimate == FALSE) re <- "sm.split"
-   if(split.w == TRUE  & df.estimate == TRUE ) re <- "sm.split.df"
+   model.q1 = split.w == FALSE & df.estimate == TRUE
+   model.q2 = split.w == TRUE  & df.estimate == FALSE
+   model.q3 = split.w == TRUE  & df.estimate == TRUE
+
+   if(model.q1) re <- "sm.df"
+   if(model.q2) re <- "sm.split"
+   if(model.q3) re <- "sm.split.df"
 
-#----
   # Block for data model ......................................................................
   dm <-
     "
@@ -547,26 +559,26 @@ blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimat
     yt[i] ~ dbin(pt[i], nt[i])
   "
 
- 
+
   #----
   # Block for the link function................................................................
   link.logit <-
   "
-  # Random effects model 
+  # Random effects model
   logit(pc[i]) <- theta.1[i]
   logit(pt[i]) <- theta.2[i] + logit(pc[i])
   "
 
   link.cloglog <-
     "
-  # Random effects model 
+  # Random effects model
   cloglog(pc[i]) <- theta.1[i]
   cloglog(pt[i]) <- theta.2[i] + cloglog(pc[i])
   "
 
   link.probit <-
     "
-  # Random effects model 
+  # Random effects model
   probit(pc[i]) <- theta.1[i]
   probit(pt[i]) <- theta.2[i] + probit(pc[i])
   "
@@ -576,7 +588,7 @@ blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimat
     "
   theta.1[i] ~ dnorm(mu.1, pre.theta.1)
   theta.2[i] ~ dnorm(mu.2.1[i], pre.theta.2.1)
-  
+
   #Conditional mean
   mu.2.1[i] <- mu.2 + rho * sigma.2 / sigma.1 * (theta.1[i] - mu.1)
 
@@ -594,7 +606,7 @@ blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimat
 
  # Conditional precision
   pre.theta.2.1 <- pre.theta.2 / (1 - rho*rho)
- 
+
 
   # Correlation
   z ~ dnorm(mean.Fisher.rho, pre.Fisher.rho)
@@ -611,7 +623,7 @@ blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimat
 
   Omega.new[1:2, 1:2] <- inverse(Sigma.new[1:2, 1:2])
         theta.new[1:2] ~ dmnorm(mu.new[1:2], Omega.new[1:2 ,1:2])
-  
+
   # Functional parameters
   beta.0 <- (mu.2 - beta.1 * mu.1)
 	beta.1 <- rho * sigma.2/sigma.1
@@ -623,27 +635,27 @@ blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimat
     "
   theta.1[i] ~ dnorm(mu.1, pre.theta.1[i])
   theta.2[i] ~ dnorm(mu.2.1[i], pre.theta.2.1[i])
-	
+
 	#Conditional mean
 	mu.2.1[i] <- mu.2 + rho * sigma.2 / sigma.1 * (theta.1[i] - mu.1)
-	
+
 	# Conditional precision
 	pre.theta.2.1[i] <- pre.theta.2[i] / (1 - rho * rho)
-	
+
 	lambda[i] ~ dchisqr(df)
     	w[i] <- df/lambda[i]
- 
+
 	pre.theta.1[i] <- pre.1 / w[i]
 	pre.theta.2[i] <- pre.2 / w[i]
 
-  # Probability of outlier	
+  # Probability of outlier
 	p.w[i] <- step(w[i]-0.99)
   }
 
   # Hyper priors
   mu.1 ~  dlogis(mean.mu.1, pre.mu.1)
 	mu.2 ~  dlogis(mean.mu.2, pre.mu.2)
-	
+
 	# Dispersion parameters
 	sigma.1 ~ dunif(0, sigma.1.upper)
 	sigma.2 ~ dunif(0, sigma.2.upper)
@@ -657,7 +669,7 @@ blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimat
   # Predictions ...
   mu.new[1] <- mu.1
 	mu.new[2] <- mu.2
-	
+
 	Sigma.new[1, 1] <- pow(sigma.1, 2)
 	Sigma.new[2, 2] <- pow(sigma.2, 2)
 	Sigma.new[1, 2] <- rho * sigma.1 * sigma.2
@@ -666,7 +678,7 @@ blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimat
   lambda.new ~ dchisqr(df)
 	w.new <- df/lambda.new
 	Omega.new[1:2,1:2] <- inverse(Sigma.new[1:2, 1:2]) / w.new
-	
+
 	theta.new[1:2] ~ dmnorm(mu.new[1:2], Omega.new[1:2 ,1:2])
 
   # Functional parameters
@@ -680,10 +692,10 @@ blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimat
     "
   theta.1[i] ~ dnorm(mu.1, pre.theta.1[i])
   theta.2[i] ~ dnorm(mu.2.1[i], pre.theta.2.1[i])
-	
+
 	#Conditional mean
 	mu.2.1[i] <- mu.2 + rho * sigma.2 / sigma.1 * (theta.1[i] - mu.1)
-	
+
 	# Conditional precision
 	pre.theta.2.1[i] <- pre.theta.2[i] / (1 - rho * rho)
 
@@ -692,7 +704,7 @@ blueprint <- function(link = "logit", re = "normal", split.w = FALSE, df.estimat
 
   lambda1[i] ~ dchisqr(df)
   w1[i] <- df/lambda1[i]
-	
+
 	lambda2[i] ~ dchisqr(df)
 	w2[i] <- df/lambda2[i]
 
@@ -796,7 +808,7 @@ re.sm.split.df <- paste(re.sm.split, prior.of.df)
 
 # List of possible models for hte ...
 
-# normal random effects 
+# normal random effects
 m1 <- paste(dm, link.logit,   re.normal, par.logit)
 m2 <- paste(dm, link.cloglog, re.normal, par.cloglog)
 m3 <- paste(dm, link.probit,  re.normal, par.probit)
@@ -913,8 +925,9 @@ return(results)
 
 
 
+
 #' Generic print function for metarisk object in jarbes.
-#' 
+#'
 #' @param x The object generated by the function metarisk.
 #'
 #' @param digits The number of significant digits printed. The default value is 3.
@@ -926,7 +939,7 @@ return(results)
 print.metarisk <- function(x, digits, ...)
 {
   print(x$BUGSoutput,...)
-  
+
 }
 
 
@@ -947,21 +960,21 @@ print.metarisk <- function(x, digits, ...)
 #'
 summary.metarisk <- function(object, digits = 3,  intervals = c(0.025, 0.5, 0.975), ...)
 {
-  
+
   print(object$BUGSoutput, digits= digits, intervals = intervals, ...)
-  
+
 }
 
 
 
 #' Generic plot function for metarisk object in jarbes.
-#' 
+#'
 #' @param x The object generated by the metarisk function.
-#' 
+#'
 #' @param ... \dots
-#' 
+#'
 #' @export
-#' 
+#'
 plot.metarisk <- function(x, ...)
 {
   plot(x)
